--*************************************
-- Corona Game Engine sample
-- Juggle soccer ball
--*************************************
-- Author: Michael Hartlef
-- Date:   October 18th, 2010
-- Email:  mike@fantomgl.com
--*************************************
--[[
--First you need to include the physics part of the Corona Game Engine
--as without it you would have to write much mroe code.
--local physics = require("physics")

--As we don't need the statusbar, we hide it
display.setStatusBar( display.HiddenStatusBar )

--Uncomment the next line if you want to see the physics shapes in action
--physics.setDrawMode( "hybrid" )

--I want to let the physics run at 60 fps per second
physics.setScale( 60 )

--And not start the physic engine.
physics.start()

--To have the ball come down again, we need to add some gravity
physics.setGravity( 0, 20 )

--Next we need a wall on each edge, so the ball stays inside the visible area
--Each wall shares the same physic body attributes. 
local borderBody =  { friction=0.5, bounce=0.0 }

--The top edge
local borderTop = display.newRect( 0, -8, display.contentWidth, 10 )
physics.addBody( borderTop, "static", borderBody )

--The botton edge
local borderBottom = display.newRect( 0, display.contentHeight-2, display.contentWidth, 10 )
physics.addBody( borderBottom, "static",borderBody )

--The left edge
local borderLeft = display.newRect( -8, 0, 10, display.contentHeight )
physics.addBody( borderLeft, "static", borderBody )

--The right edge
local borderRight = display.newRect( display.contentWidth-2, 0, 10, display.contentHeight )
physics.addBody( borderRight, "static", borderBody )

--next load in a nice background image
local background = display.newImage("field.png", 0, 0 )



--Next we define the balls physic body
local ballBody = { density=0.7, friction=0.2, bounce=0.6, radius=32 }

--And load the ball image
local soccerball = display.newImage("ball.png", 0, 0 )

--Set the reference points of the ball to its center
soccerball.xreference=16
soccerball.yreference=16

--Position the ball finally on the screen
soccerball.x=display.contentWidth/2
soccerball.y=30

--Add the physic body to the display object
physics.addBody( soccerball, ballBody)

--This function deals with the touch of our finger, so we can try to juggle the ball
--in the air. I use a touch event, as the tap event fires only when the finger leaves
--the screen
function onTouch(event)
	--We want only some action, when the finger touches the ball
	if event.phase == "began" then
		--We modify the y-coordinate of the event, so it is more under the ball
		event.y = event.y+20
		--Now apply some physic force to the ball reagrding the relative position
		--of the touch coordinates and the ball coordinates.
		soccerball:applyForce( (soccerball.x - event.x)*20, (soccerball.y - event.y)*20, soccerball.x, soccerball.y )
	end
end


soccerball:addEventListener("touch",onTouch)
--]]